@@ -366,7 +366,7 @@ static function_lookup_t FUNCTION_LOOKUP_TABLE[] = {
 		"Floating-point seconds since the epoch,\n"
 		"e.g. 1440768801.748936." },
 
-	{FUNC_CLASS_TYPING, "is_absent",      1,0, "False if field is present in input, false otherwise"},
+	{FUNC_CLASS_TYPING, "is_absent",      1,0, "False if field is present in input, true otherwise"},
 	{FUNC_CLASS_TYPING, "is_bool",        1,0, "True if field is present with boolean value. Synonymous with is_boolean."},
 	{FUNC_CLASS_TYPING, "is_boolean",     1,0, "True if field is present with boolean value. Synonymous with is_bool."},
 	{FUNC_CLASS_TYPING, "is_empty",       1,0, "True if field is present in input with empty string value, false otherwise."},
@@ -608,6 +608,25 @@ void fmgr_list_all_functions_raw(fmgr_t* pfmgr, FILE* output_stream) {
 	}
 }
 
+void fmgr_list_all_functions_as_table(fmgr_t* pfmgr, FILE* output_stream) {
+	fprintf(output_stream, "%-30s %-10s %s\n", "Name", "Class", "#Args");
+	for (int i = 0; ; i++) {
+		function_lookup_t* plookup = &FUNCTION_LOOKUP_TABLE[i];
+		if (plookup->function_name == NULL) // end of table
+			break;
+
+		fprintf(output_stream, "%-30s %-10s ",
+			plookup->function_name,
+			function_class_to_desc(plookup->function_class));
+		if (plookup->variadic) {
+			fprintf(output_stream, "variadic");
+		} else {
+			fprintf(output_stream, "%d", plookup->arity);
+		}
+		fprintf(output_stream, "\n");
+	}
+}
+
 // ================================================================
 typedef struct _udf_callsite_state_t {
 	int arity;
