@@ -124,10 +124,10 @@ static char* test_long_short() {
 static char* test_dkvp() {
 	char* test_name = "dkvp";
 	char* strings[] = { "=" , ",", "\r\n", "\xff" };
-	const int PS_STRIDX  = 0;
-	const int FS_STRIDX  = 1;
-	const int RS_STRIDX  = 2;
-	const int EOF_STRIDX = 3;
+	const int PS_TOKEN  = 0;
+	const int FS_TOKEN  = 1;
+	const int RS_TOKEN  = 2;
+	const int EOF_TOKEN = 3;
 	int num_strings = sizeof(strings) / sizeof(strings[0]);
 	char* buf =
 		"abc=123,def=456\r\n"
@@ -153,8 +153,8 @@ static char* test_dkvp() {
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen);
 	mu_assert_lf(rc == TRUE);
-	mu_assert_lf(stridx == PS_STRIDX);
-	mu_assert_lf(matchlen == strlen(strings[PS_STRIDX]));
+	mu_assert_lf(stridx == PS_TOKEN);
+	mu_assert_lf(matchlen == strlen(strings[PS_TOKEN]));
 	p += matchlen;
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen); mu_assert_lf(rc == FALSE); p++;
@@ -163,8 +163,8 @@ static char* test_dkvp() {
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen);
 	mu_assert_lf(rc == TRUE);
-	mu_assert_lf(stridx == FS_STRIDX);
-	mu_assert_lf(matchlen == strlen(strings[FS_STRIDX]));
+	mu_assert_lf(stridx == FS_TOKEN);
+	mu_assert_lf(matchlen == strlen(strings[FS_TOKEN]));
 	p += matchlen;
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen); mu_assert_lf(rc == FALSE); p++;
@@ -173,8 +173,8 @@ static char* test_dkvp() {
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen);
 	mu_assert_lf(rc == TRUE);
-	mu_assert_lf(stridx == PS_STRIDX);
-	mu_assert_lf(matchlen == strlen(strings[PS_STRIDX]));
+	mu_assert_lf(stridx == PS_TOKEN);
+	mu_assert_lf(matchlen == strlen(strings[PS_TOKEN]));
 	p += matchlen;
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen); mu_assert_lf(rc == FALSE); p++;
@@ -183,8 +183,8 @@ static char* test_dkvp() {
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen);
 	mu_assert_lf(rc == TRUE);
-	mu_assert_lf(stridx == RS_STRIDX);
-	mu_assert_lf(matchlen == strlen(strings[RS_STRIDX]));
+	mu_assert_lf(stridx == RS_TOKEN);
+	mu_assert_lf(matchlen == strlen(strings[RS_TOKEN]));
 	p += matchlen;
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen); mu_assert_lf(rc == FALSE); p++;
@@ -193,8 +193,8 @@ static char* test_dkvp() {
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen);
 	mu_assert_lf(rc == TRUE);
-	mu_assert_lf(stridx == PS_STRIDX);
-	mu_assert_lf(matchlen == strlen(strings[PS_STRIDX]));
+	mu_assert_lf(stridx == PS_TOKEN);
+	mu_assert_lf(matchlen == strlen(strings[PS_TOKEN]));
 	p += matchlen;
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen); mu_assert_lf(rc == FALSE); p++;
@@ -203,8 +203,8 @@ static char* test_dkvp() {
 
 	rc = parse_trie_ring_match(ptrie, p, 0, strlen(p), 0xff, &stridx, &matchlen);
 	mu_assert_lf(rc == TRUE);
-	mu_assert_lf(stridx == EOF_STRIDX);
-	mu_assert_lf(matchlen == strlen(strings[EOF_STRIDX]));
+	mu_assert_lf(stridx == EOF_TOKEN);
+	mu_assert_lf(matchlen == strlen(strings[EOF_TOKEN]));
 	p += matchlen;
 
 	return 0;
@@ -214,7 +214,7 @@ static char* test_dkvp() {
 static char* show_it() {
 	char* test_name = "show_it";
 	char* strings[] = { "=" , ",", "\r\n", "\xff" };
-	const int EOF_STRIDX = 3;
+	const int EOF_TOKEN = 3;
 	int num_strings = sizeof(strings) / sizeof(strings[0]);
 	char* buf =
 		"abc=123,def=456\r\n"
@@ -242,7 +242,7 @@ static char* show_it() {
 			printf(")\n");
 
 			p += matchlen;
-			if (stridx == EOF_STRIDX) {
+			if (stridx == EOF_TOKEN) {
 				break;
 			}
 		} else {
